% Demo for the No Information Rate or Null Information Rate
% see the arxiv document:
% 
% Manuele Bicego, Antonella Mensi: "Null/No Information Rate (NIR): a statistical 
% test to assess if a classification accuracy is significant for a given problem",
% arXiv preprint arXiv:2306.06140, 2023
%
%
% (c) Manuele Bicego 
% University of Verona (Italy)
% Last update: June 2023
% 
% The code is provided on an “as is” without support or guarantees.
%



% Ntrain = vector of c elements (c number of classes of the problem)
% where
% Ntrain(1) = number of objects of class 1 in the training set
% Ntrain(2) = number of objects of class 2 in the training set
% ...
Ntrain = [150 150 200]; % 3 classes, the first two with 150 objects, the third with 200
Ntest = [1000 1000 1500]; % same as NTrain but for testing set
                   
% Number of objects correctly classified, number of objects in the testing
% set (eq 1 and 2)
Correct  = 1600; % correctly classified objects

% Computing test
[pRand, pNIR,accNIR] = NIRTest(Correct,Ntrain,Ntest);

% PRinting results
fprintf('NIR tests\n')
fprintf('--  %.4f: accuracy of the Classifier on the testing set\n',Correct/sum(Ntest));
fprintf('--  %.4f: accuracy Random Classifier \n',1/length(Ntest));
fprintf('--  %.4f: accuracy a priori Classifier (NIR)\n',accNIR);
fprintf('\nResults:\n');
fprintf('p-value for Random: %.3g\n',pRand);
fprintf('p-value for NIR   : %.3g\n',pNIR);






